@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.TimestreamQuery 1.17.63\n"
-        "Version:         1.17.63.0\n"
-        "Builder version: 4.8.1\n"
+        "Type annotations for boto3.TimestreamQuery 1.17.90\n"
+        "Version:         1.17.90\n"
+        "Builder version: 4.15.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-timestream-query/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.63.0")
+    print("1.17.90")
 
 
 def main() -> None:
