@@ -17,8 +17,8 @@ from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_timestream_query.paginator import QueryPaginator
-from mypy_boto3_timestream_query.type_defs import (
+from .paginator import QueryPaginator
+from .type_defs import (
     CancelQueryResponseTypeDef,
     DescribeEndpointsResponseTypeDef,
     QueryResponseTypeDef,
@@ -54,7 +54,7 @@ class Exceptions:
 
 class TimestreamQueryClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html)
     """
 
@@ -63,20 +63,20 @@ class TimestreamQueryClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#can_paginate)
         """
 
-    def cancel_query(self, QueryId: str) -> CancelQueryResponseTypeDef:
+    def cancel_query(self, *, QueryId: str) -> CancelQueryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery.Client.cancel_query)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#cancel-query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery.Client.cancel_query)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#cancel_query)
         """
 
     def describe_endpoints(self) -> DescribeEndpointsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery.Client.describe_endpoints)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#describe-endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery.Client.describe_endpoints)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#describe_endpoints)
         """
 
     def generate_presigned_url(
@@ -87,19 +87,24 @@ class TimestreamQueryClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#generate_presigned_url)
         """
 
     def query(
-        self, QueryString: str, ClientToken: str = None, NextToken: str = None, MaxRows: int = None
+        self,
+        *,
+        QueryString: str,
+        ClientToken: str = None,
+        NextToken: str = None,
+        MaxRows: int = None
     ) -> QueryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery.Client.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery.Client.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/client.html#query)
         """
 
     def get_paginator(self, operation_name: Literal["query"]) -> QueryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/timestream-query.html#TimestreamQuery.Paginator.Query)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/paginators.html#querypaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/timestream-query.html#TimestreamQuery.Paginator.Query)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_timestream_query/paginators.html#querypaginator)
         """
