@@ -19,11 +19,11 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("QueryPaginatorName", "ScalarType")
+__all__ = ("QueryPaginatorName", "ScalarTypeType")
 
 
 QueryPaginatorName = Literal["query"]
-ScalarType = Literal[
+ScalarTypeType = Literal[
     "BIGINT",
     "BOOLEAN",
     "DATE",
